netapp_ontap.models.cluster_nodes_ha_giveback API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_ha_giveback`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesHaGivebackSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesHaGiveback object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `failure: ClusterNodesHaGivebackFailure GET POST PATCH`

    Indicates the failure code and message. This property is not supported on the ASA r2 platform.

  `state: str GET POST PATCH`

    The state field of the cluster_nodes_ha_giveback.

    Valid choices:

    - nothing_to_giveback
    - not_attempted
    - in_progress
    - failed
  `status: List[GivebackStatus] GET`

    Giveback status of each aggregate. This property is not supported on the ASA r2 platform.